==> vue-card-group-2.22.1.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/card-group/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "size-large": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.112),1fr))]",
  "size-medium": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.72),1fr))]",
  "size-small": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.54),1fr))]",
  "size-mini": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.32),1fr))]"
};
var __vue2_script = defineComponent({
  name: $prefix + "CardGroup",
  componentName: "CardGroup",
  emits: ["update:modelValue", "change"],
  props: [].concat(props, ["modelValue", "customClass", "height", "autoWidth", "size", "status", "checkType", "type", "disabled"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-full grid gap-4",
    class: _vm.gcls("size-" + _vm.state.size),
    attrs: {
      "data-tag": "tiny-card-group"
    }
  }, [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-card-group-2.23.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/card-group/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { iconGridNoData } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "size-large": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.112),1fr))]",
  "size-medium": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.72),1fr))]",
  "size-small": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.54),1fr))]",
  "size-mini": "grid-cols-[repeat(auto-fill,minmax(theme(spacing.32),1fr))]"
};
var __vue2_script = defineComponent({
  name: $prefix + "CardGroup",
  componentName: "CardGroup",
  components: {
    IconGridNoData: iconGridNoData()
  },
  emits: ["update:modelValue", "change"],
  props: [].concat(props, ["modelValue", "customClass", "height", "autoWidth", "size", "status", "checkType", "type", "disabled"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-full grid gap-4",
    class: _vm.gcls("size-" + _vm.state.size),
    attrs: {
      "data-tag": "tiny-card-group"
    }
  }, [_vm._t("default"), _c("icon-grid-no-data", {
    staticClass: "hidden first:block !w-full !h-28",
    attrs: {
      "data-tag": "tiny-card-group-empty"
    }
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
